=== modified file 'bzrlib/branch.py'
--- bzrlib/branch.py	2006-01-18 13:45:16 +0000
+++ bzrlib/branch.py	2006-01-19 21:25:01 +0000
@@ -20,6 +20,7 @@
 import os
 import errno
 from warnings import warn
+import xml.sax.saxutils
 from cStringIO import StringIO
 
 
@@ -1181,7 +1182,7 @@
             if start < 9: continue
             end = line.find('"',start)
             assert end>= 0
-            file_id = line[start:end]
+            file_id = xml.sax.saxutils.unescape(line[start:end])
 
             # check if file_id is already present
             if file_id in file_ids: continue
@@ -1190,7 +1191,7 @@
             if start < 10: continue
             end = line.find('"',start)
             assert end>= 0
-            revision_id = line[start:end]
+            revision_id = xml.sax.saxutils.unescape(line[start:end])
 
             if revision_id in changes:
                 file_ids.add(file_id)

=== modified file 'bzrlib/tests/test_fileid_involved.py'
--- bzrlib/tests/test_fileid_involved.py	2005-12-15 21:37:04 +0000
+++ bzrlib/tests/test_fileid_involved.py	2006-01-19 21:25:01 +0000
@@ -41,8 +41,13 @@
         main_branch = Branch.initialize('.')
         self.build_tree(["a","b","c"])
 
-        smart_add('.')
-        commit(Branch.open("."), "Commit one", rev_id="rev-A")
+        b = Branch.open('.')
+        wt = b.working_tree()
+        wt.add(['a', 'b', 'c'], ['a-file-id-2006-01-01-abcd',
+                                 'b-file-id-2006-01-01-defg',
+                                 'c-funky<file-id> quiji%bo'])
+        commit(b, "Commit one", rev_id="rev-A")
+        del b, wt
         #-------- end A -----------
 
         copy_branch(main_branch,"../branch1")
@@ -88,7 +93,6 @@
         os.chdir("../branch2")
 
         self.touch("c")
-        smart_add('.')
         commit(Branch.open("."), "branch2, commit two", rev_id="rev-K")
 
         #-------- end K -----------
@@ -98,7 +102,8 @@
         self.touch("b")
         self.merge("../branch1",force=True)
 
-        commit(Branch.open("."), "merge branch1, rev-12", rev_id="rev-D")
+        # D gets some funky characters to make sure the unescaping works
+        commit(Branch.open("."), "merge branch1, rev-12", rev_id="rev-<D>")
 
         # end D
 
@@ -125,7 +130,7 @@
         l = self.branch.fileid_involved_between_revs("rev-B","rev-K" )
         self.assertEquals( sorted(map( lambda x: x[0], l )), ["b","c"])
 
-        l = self.branch.fileid_involved_between_revs("rev-C","rev-D" )
+        l = self.branch.fileid_involved_between_revs("rev-C","rev-<D>" )
         self.assertEquals( sorted(map( lambda x: x[0], l )), ["b","d"])
 
         l = self.branch.fileid_involved_between_revs("rev-C","rev-G" )
@@ -140,18 +145,18 @@
         l = self.branch.fileid_involved_by_set(set(["rev-B"]))
         self.assertEquals( sorted(map( lambda x: x[0], l )), ["a"])
 
-        l = self.branch.fileid_involved_by_set(set(["rev-D"]))
+        l = self.branch.fileid_involved_by_set(set(["rev-<D>"]))
         self.assertEquals( sorted(map( lambda x: x[0], l )), ["b"])
 
     def test_fileid_involved_compare(self):
 
-        l1 = self.branch.fileid_involved_between_revs("rev-E", "rev-D")
-        l2 = self.branch.fileid_involved_by_set(set(["rev-D","rev-F","rev-C","rev-B"]))
+        l1 = self.branch.fileid_involved_between_revs("rev-E", "rev-<D>")
+        l2 = self.branch.fileid_involved_by_set(set(["rev-<D>","rev-F","rev-C","rev-B"]))
         self.assertEquals( l1, l2 )
 
         l1 = self.branch.fileid_involved_between_revs("rev-C", "rev-G")
         l2 = self.branch.fileid_involved_by_set(
-            set(["rev-G","rev-D","rev-F","rev-K","rev-J"]))
+            set(["rev-G","rev-<D>","rev-F","rev-K","rev-J"]))
         self.assertEquals( l1, l2 )
 
     def test_fileid_involved_full_compare(self):

=== modified file 'bzrlib/xml4.py'
--- bzrlib/xml4.py	2005-11-10 03:03:53 +0000
+++ bzrlib/xml4.py	2006-01-19 21:25:01 +0000
@@ -13,7 +13,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 
-from bzrlib.xml import ElementTree, SubElement, Element, Serializer
+from bzrlib.xml_serializer import ElementTree, SubElement, Element, Serializer
 from bzrlib.inventory import ROOT_ID, Inventory, InventoryEntry
 import bzrlib.inventory as inventory
 from bzrlib.revision import Revision        

=== modified file 'bzrlib/xml5.py'
--- bzrlib/xml5.py	2005-11-04 14:33:19 +0000
+++ bzrlib/xml5.py	2006-01-19 21:25:01 +0000
@@ -13,7 +13,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 
-from bzrlib.xml import ElementTree, SubElement, Element, Serializer
+from bzrlib.xml_serializer import ElementTree, SubElement, Element, Serializer
 from bzrlib.inventory import ROOT_ID, Inventory, InventoryEntry
 import bzrlib.inventory as inventory
 from bzrlib.revision import Revision        

=== renamed file 'bzrlib/xml.py' => 'bzrlib/xml_serializer.py'
